CompatibleBaggingClassifier
=================================================================================

.. currentmodule:: imbalanced_ensemble.ensemble.compatible

.. autoclass:: CompatibleBaggingClassifier

   

   
   .. rubric:: Methods

   .. autosummary::
   
      
      
        ~CompatibleBaggingClassifier.decision_function
      
      
        ~CompatibleBaggingClassifier.fit
      
      
        ~CompatibleBaggingClassifier.get_params
      
      
        ~CompatibleBaggingClassifier.predict
      
      
        ~CompatibleBaggingClassifier.predict_log_proba
      
      
        ~CompatibleBaggingClassifier.predict_proba
      
      
        ~CompatibleBaggingClassifier.score
      
      
        ~CompatibleBaggingClassifier.set_params
      
   
   

.. include:: ../../../back_references/imbalanced_ensemble.ensemble.compatible.CompatibleBaggingClassifier.examples

.. raw:: html

    <div style='clear:both'></div>